package de.hft.stuttgart.citydoctor2.webservice.model.entities;

import java.util.ArrayList;
import java.util.List;

import javax.persistence.Access;
import javax.persistence.AccessType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.validation.constraints.NotNull;

import de.hft.stuttgart.citydoctor2.webservice.model.ValidationStatus;

@Entity
@Table(name = "validations")
public class Validation {
	
	@Id
	@GeneratedValue(strategy = GenerationType.IDENTITY)
	@Access(AccessType.PROPERTY)
	private int id;

	@ManyToOne
	@NotNull
	private WebCityDoctorModel model;
	
	@NotNull
	private ValidationStatus status;
	
	@NotNull
	private String name;
	
	@OneToMany(mappedBy = "validation", orphanRemoval = true)
	private List<WebError> errors = new ArrayList<>();
	
	@OneToMany(mappedBy = "validation", orphanRemoval = true)
	private List<FeatureValidationStatus> errorStatus = new ArrayList<>();
	
	@Column(name = "pdf_report")
	private byte[] pdfReport;
	
	@Column(name = "xml_report")
	private byte[] xmlReport;
	
	public Validation() {
	}
	
	public Validation(@NotNull WebCityDoctorModel model, @NotNull ValidationStatus status, @NotNull String name) {
		super();
		this.model = model;
		this.status = status;
		this.name = name;
	}

	public List<FeatureValidationStatus> getErrorStatus() {
		return errorStatus;
	}

	public void setErrorStatus(List<FeatureValidationStatus> errorStatus) {
		this.errorStatus = errorStatus;
	}

	public List<WebError> getErrors() {
		return errors;
	}

	public void setErrors(List<WebError> errors) {
		this.errors = errors;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public WebCityDoctorModel getModel() {
		return model;
	}

	public void setModel(WebCityDoctorModel model) {
		this.model = model;
	}

	public ValidationStatus getStatus() {
		return status;
	}

	public void setStatus(ValidationStatus status) {
		this.status = status;
	}

	public byte[] getPdfReport() {
		return pdfReport;
	}

	public void setPdfReport(byte[] pdfReport) {
		this.pdfReport = pdfReport;
	}

	public byte[] getXmlReport() {
		return xmlReport;
	}

	public void setXmlReport(byte[] xmlReport) {
		this.xmlReport = xmlReport;
	}
	
}
